@@ -8,8 +8,6 @@ from embed.models import EmbedCache
 
 
 class Embed(object):
-
-
 	consumer_key = None
 	consumer_secret = None
 	oauth_token = None
@@ -71,12 +69,12 @@ class Embed(object):
 		tweet, created = EmbedCache.objects.get_or_create(service="twitter", embed_id=id)
 
 		if tweet.embed_code is None:
-			auth = OAuth1(unicode(cls.consumer_key), unicode(cls.consumer_secret), unicode(cls.oauth_token), unicode(cls.oauth_token_secret), signature_type="auth_header")
 			params = dict()
 			params = cls.config
 			params['id'] =  id
 			params['maxwidth'] = cls.config['width']
 
+			auth = OAuth1(unicode(cls.consumer_key), unicode(cls.consumer_secret), unicode(cls.oauth_token), unicode(cls.oauth_token_secret), signature_type="auth_header")
 			r = requests.get(cls.twitter_embed_url, auth=auth, params=params)
 
 			if r.status_code == 200:
@@ -97,21 +95,8 @@ class Embed(object):
 
 			
 		for id in ids:
-			tweet, created = EmbedCache.objects.get_or_create(service="twitter", embed_id=id)
-
-			if tweet.embed_code is None:
-				params = dict()
-				params = cls.config
-				params['id'] = id
-
-				auth = OAuth1(unicode(cls.consumer_key), unicode(cls.consumer_secret), unicode(cls.oauth_token), unicode(cls.oauth_token_secret), signature_type="auth_header")
-				r = requests.get(cls.twitter_embed_url, auth=auth, params=params)
-				
-				if r.status_code == 200:
-					tweet.embed_code = '<div class="tweet-container">' + r.json['html'] + '</div>'
-					tweet.save()
-
-			string = re.sub(r'(?<![href="|src="])http[s]?://(%s)%s'%(cls.twitter_pattern_search, id), tweet.embed_code, string)
+			embed_code = cls.get_twitter_embed_by_id(id)
+			string = re.sub(r'(?<![href="|src="])http[s]?://(%s)%s'%(cls.twitter_pattern_search, id), embed_code, string)
 
 		return mark_safe(string)
 
